.. _Installation:

Installation
============

While this library is pre-alpha, it is recommended to install it with pip using the `--upgrade` flag so
that you always get the latest version.

Note that until the API of this library will be unstable and subject to change until this library becomes beta.

.. code-block:: bash

   pip3 install --upgrade hpecp

